==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/PolarSplineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PolarLineSeriesBaseDescriptionMetadata } from "./PolarLineSeriesBaseDescriptionMetadata";
import { PolarSplineSeriesDescription } from "./PolarSplineSeriesDescription";
/**
 * @hidden
 */
export let PolarSplineSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class PolarSplineSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (PolarSplineSeriesDescriptionMetadata.a == null) {
                PolarSplineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PolarSplineSeriesDescriptionMetadata.c(PolarSplineSeriesDescriptionMetadata.a);
            }
            if (a.k(PolarSplineSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ab(PolarSplineSeriesDescriptionMetadata.a);
        }
        static c(a) {
            PolarLineSeriesBaseDescriptionMetadata.c(a);
            a.item("Stiffness", "Number:double");
        }
        static d(a) {
            PolarSplineSeriesDescriptionMetadata.b(a);
            a.ad("PolarSplineSeries", () => new PolarSplineSeriesDescription());
            a.ac("PolarSplineSeries", PolarSplineSeriesDescriptionMetadata.a);
        }
    }
    PolarSplineSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(PolarSplineSeriesDescriptionMetadata, 'PolarSplineSeriesDescriptionMetadata');
    PolarSplineSeriesDescriptionMetadata.a = null;
    return PolarSplineSeriesDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/PolarSplineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PolarLineSeriesBaseDescriptionMetadata } from "./PolarLineSeriesBaseDescriptionMetadata";
import { PolarSplineSeriesDescription } from "./PolarSplineSeriesDescription";
/**
 * @hidden
 */
export let PolarSplineSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class PolarSplineSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (PolarSplineSeriesDescriptionMetadata.a == null) {
                PolarSplineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PolarSplineSeriesDescriptionMetadata.c(PolarSplineSeriesDescriptionMetadata.a);
            }
            if (a.k(PolarSplineSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ac(PolarSplineSeriesDescriptionMetadata.a);
        }
        static c(a) {
            PolarLineSeriesBaseDescriptionMetadata.c(a);
            a.item("Stiffness", "Number:double");
        }
        static d(a) {
            PolarSplineSeriesDescriptionMetadata.b(a);
            a.ae("PolarSplineSeries", () => new PolarSplineSeriesDescription());
            a.ad("PolarSplineSeries", PolarSplineSeriesDescriptionMetadata.a);
        }
    }
    PolarSplineSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(PolarSplineSeriesDescriptionMetadata, 'PolarSplineSeriesDescriptionMetadata');
    PolarSplineSeriesDescriptionMetadata.a = null;
    return PolarSplineSeriesDescriptionMetadata;
})();
